/* $Workfile: AlvisWatchDog.c $       $Revision: 2 $      $Modtime: 6/10/09 6:08p $  */
/*******************************************************************************

    Copyright (C) 2008-2009 Odin TeleSystems Inc., All Rights Reserved

  @module

    AlvisWatchDog.c

    This demo programs shows how to enable the hardware watchdog in Alvis 
    DaVinci processor. Once the watchdog is enabled it needs to be pinged 
    at a regular interval, or the system will reboot automatically.

    The watchdog has a hardcoded timeout of 64 seconds.

    This app will enable the watchdog (open the /dev/watchdog device), and
    keep pinging it every 10 seconds.

    Once the watchdog is enabled it will stay enabled until a reboot of the system.

*******************************************************************************/

#include <stdio.h>
#include <stdlib.h>
#include <unistd.h>
#include <fcntl.h>
#include <sys/ioctl.h>
#include <linux/watchdog.h>
#include <signal.h>


static int fd = 0;


/*******************************************************************************
  @func
    
*******************************************************************************/
int main() 
{
  int rc;
  int arg;

  // Open the Watchdog device. From this point we have to ping the Watchdog before it times out,
  // or the system will reboot automatically.
  fd = open( "/dev/watchdog", O_WRONLY );

  if( fd == -1 ) {
    fprintf( stderr, "Error: Cannot open /dev/watchdog\n" );
    return 1;
  } else {
    printf("Opened /dev/watchdog. The watchdog is now enabled.\n");
  }

  // Query the timeout (in seconds) for the Watchdog (optional)
  rc = ioctl( fd, WDIOC_GETTIMEOUT, &arg );

  if (rc == 0) {
    printf("WatchDog timeout = %d seconds\n", arg);
  } else {
    fprintf( stderr, "Error: WDIOC_GETTIMEOUT call failed (rc=%d)\n", rc);
    return 1;
  }
  
  // Keep pinging the Watchdog (mandatory)
  // We need to ping it at least once every 64 seconds (as the Watchdog time was 64 seconds as of this writing).
  // If we don't ping it before the timeout the system will reboot.
  // We have chosen to ping it every 10 seconds.
  printf("Pinging the Watchdog every 10 seconds.\n");
  while (1) {
    rc = ioctl( fd, WDIOC_KEEPALIVE, 0 );
    //printf("Pinged the Watchdog. (rc=%d)\n", rc);

    usleep( 10*1000*1000 ); // 10*1000*1000 is 10 seconds

    //rc = ioctl( fd, WDIOC_GETSTATUS, &arg );
    //printf("WDIOC_GETSTATUS returned %d (rc=%d)\n", arg, rc);
  }
  
  // We will never get here
  return 0;
}


/*******************************************************************************

  Copyright (C) Odin TeleSystems Inc., 2008-2009


  All rights reserved. No part of this computer program may be reproduced,
  stored in any retrieval system, or transmitted, in any form or by any
  means, electronic, mechanical, photocopying, recording, or otherwise,
  without the prior written permission of Odin TeleSystems Inc., or without
  a permission stipulated in the agreement/contract under which this computer
  program was supplied.

*******************************************************************************/

