/* $Workfile: OtxSlic.h $   $Revision: 10 $    $Modtime: 5/06/05 4:07p $  */
#ifndef OTX_SLIC_H
#define OTX_SLIC_H
/*******************************************************************************

  @doc PublicHwApi OtxSlic

  Copyright (C) 2005 Odin TeleSystems Inc., All Rights Reserved

  OTX Generic Hardware Driver API

  @module
  OtxSlic | OTX Logical Device Function Prototypes for C54CST DSP related devices

  @contents2
  OtxSlic.h |

  @index func | OtxSlic

  @contents2
  OTX Slic Related Functions - OtxSlicXXX() | Functions available for physical devices hosted by Arni boards

  @head3 OtxSlicXXX() Function Reference |

  @index func | OtxSlic

*******************************************************************************/

#include "OtxType.h"
#include "OtxDef.h"

#include "OtxSlicD.h"
#include "OtxDataD.h"


#ifdef __cplusplus
extern "C" {
#endif


/*******************************************************************************

  @func
    Set the state of the Reset Pin for the Slic device.

  @comm
    The Slic is held in this state until the next OtxSlicSetResetPin() is received.

  @ex |
    // Put Slics into a reset state
    for(i=0; i < DEMO_LI_MAX; i++) {
      result = OtxSlicSetResetPin(g_hPhysDevs.hSlicLi[i], 
                                  OTX_TRUE);  // Assert the RESET pin
      DemoCheckRc(g_hPhysDevs.hSlicLi[i], result);
    }

    // Remove Slic from reset state
    for(i=0; i < DEMO_LI_MAX; i++) {
      result = OtxSlicSetResetPin(g_hPhysDevs.hSlicLi[i], 
                                  OTX_FALSE);  // Deassert the RESET pin
      DemoCheckRc(g_hPhysDevs.hSlicLi[i], result);
    }


*******************************************************************************/
OTX_EXPORT OTX_RESULT OTX_API OtxSlicSetResetPin(
  IN OTX_HANDLE       hDevice,            // @parm A handle to a POTS line device.
  IN OTX_BOOL         bReset              // @parm Set to OTX_TRUE to activate (assert) the Reset pin of the device, Set to OTX_FALSE to inactivate (deassert) the Reset pin of the device
);

/*******************************************************************************

  @func
    Get the current hook status for the device from the driver

  @ex |

    OtxSlicGetHookState( g_hPhysDevs.hSlicLi[1], &hookStatus );
    
    if(hookStatus == OTX_SLIC_CS_ONHOOK) {
      DemoLogf("Current line 1 status is ON-HOOK\n");  
    }
    else {
      DemoLogf("Current line 1 status is OFF-HOOK\n");  
    }

*******************************************************************************/
OTX_EXPORT OTX_RESULT OTX_API OtxSlicGetHookState(
  IN OTX_HANDLE       hDevice,            // @parm A handle to a POTS line device.
  OUT OTX_UINT32     *hookStatus          // @parm OTX_SLIC_CS_ONHOOK or OTX_SLIC_CS_OFFHOOK hook status
);

/*******************************************************************************

  @func
    Enable Dial Tone for the device

  @comm
    The tone is stated immediately when this function is called.

  @ex |
    result = OtxSlicEnableDialTone( g_hPhysDevs.hSlicLi[deviceNumber] );
    DemoCheckRc(g_hPhysDevs.hSlicLi[deviceNumber], result);

*******************************************************************************/
OTX_EXPORT OTX_RESULT OTX_API OtxSlicEnableDialTone(
  IN OTX_HANDLE       hDevice             // @parm A handle to a POTS line device.
);


/*******************************************************************************

  @func
    Enable Busy Tone for the device

  @comm
    The tone is stated immediately when this function is called.

  @ex |
    result = OtxSlicEnableBusyTone( g_hPhysDevs.hSlicLi[deviceNumber] );
    DemoCheckRc(g_hPhysDevs.hSlicLi[deviceNumber], result);

*******************************************************************************/
OTX_EXPORT OTX_RESULT OTX_API OtxSlicEnableBusyTone(
  IN OTX_HANDLE       hDevice             // @parm A handle to a POTS line device.
);


/*******************************************************************************

  @func
    Enable Reorder Tone for the device

  @comm
    The tone is stated immediately when this function is called.

  @ex |
    result = OtxSlicEnableReorderTone( g_hPhysDevs.hSlicLi[deviceNumber] );
    DemoCheckRc(g_hPhysDevs.hSlicLi[deviceNumber], result);

*******************************************************************************/
OTX_EXPORT OTX_RESULT OTX_API OtxSlicEnableReorderTone(
  IN OTX_HANDLE       hDevice             // @parm A handle to a POTS line device.
);


/*******************************************************************************

  @func
    Enable Congestion Tone for the device

  @comm
    The tone is stated immediately when this function is called.

  @ex |
    result = OtxSlicEnableCongestionTone( g_hPhysDevs.hSlicLi[deviceNumber] );
    DemoCheckRc(g_hPhysDevs.hSlicLi[deviceNumber], result);

*******************************************************************************/
OTX_EXPORT OTX_RESULT OTX_API OtxSlicEnableCongestionTone(
  IN OTX_HANDLE       hDevice             // @parm A handle to a POTS line device.
);


/*******************************************************************************

  @func
    Enable Ring Back Tone for the device

  @comm
    The tone is stated immediately when this function is called.

  @ex |
    result = OtxSlicEnableRingBackTone( g_hPhysDevs.hSlicLi[deviceNumber] );
    DemoCheckRc(g_hPhysDevs.hSlicLi[deviceNumber], result);

*******************************************************************************/
OTX_EXPORT OTX_RESULT OTX_API OtxSlicEnableRingBackTone(
  IN OTX_HANDLE       hDevice             // @parm A handle to a POTS line device.
);


/*******************************************************************************

  @func
    Enable the ring cadence for the Slic device

  @comm
    The ring is stated immediately when this function is called.

  @ex |
    result = OtxSlicStartRingState( g_hPhysDevs.hSlicLi[deviceNumber], 
                                    &slicState );
    DemoCheckRc(g_hPhysDevs.hSlicLi[deviceNumber], result);

*******************************************************************************/
OTX_EXPORT OTX_RESULT OTX_API OtxSlicStartRingState(
  IN OTX_HANDLE       hDevice,            // @parm A handle to a POTS line device.
  OUT OTX_UINT32     *slicState           // @parm current OtxSlicDeviceCallState
);


/*******************************************************************************

  @func
    Stop the ringing on the Slic device

  @comm
    The ring is stopped immediately when this function is called.

  @ex |
    result = OtxSlicStopRingState( g_hPhysDevs.hSlicLi[deviceNumber], 
                                    &slicState );
    DemoCheckRc(g_hPhysDevs.hSlicLi[deviceNumber], result);

*******************************************************************************/
OTX_EXPORT OTX_RESULT OTX_API OtxSlicStopRingState(
  IN OTX_HANDLE       hDevice,            // @parm A handle to a POTS line device.
  OUT OTX_UINT32     *slicState           // @parm current OtxSlicDeviceCallState
);


/*******************************************************************************

  @func
    Perform a TIP and RING polarity reversal to signal disconnect 
    the Slic device that the connection has been terminated.

  @comm
    The voltage polarity is reversed for a short time and then returned 
    to the normal voltage state. The delay counter is used to determine 
    the duration of the polarity shift. Normally the polarity reversal
    is held for the number of ticks specified by the delay count. The value
    of negative 1 (-1) will cause the polarity reversal to be held until the
    on-hook state is detected. All other negative values will use the driver
    default value of one tick (1 milliSecond) delay.

  @ex |
    OTX_INT32 polarityDealy;
    polarityDealy = 10; // hold polarity reversal for 10 milliSeconds
    result = OtxSlicSignalDisconnectState( g_hPhysDevs.hSlicLi[deviceNumber],
                                           polarityDealy,
                                           &slicState );
    DemoCheckRc(g_hPhysDevs.hSlicLi[deviceNumber], result);


    OTX_INT32 polarityDealy;
    polarityDealy = -1; // hold polarity reversal for as long as the hand set is off hook
    result = OtxSlicSignalDisconnectState( g_hPhysDevs.hSlicLi[deviceNumber],
                                           polarityDealy,
                                           &slicState );
    DemoCheckRc(g_hPhysDevs.hSlicLi[deviceNumber], result);

*******************************************************************************/
OTX_EXPORT OTX_RESULT OTX_API OtxSlicSignalDisconnectState(
  IN OTX_HANDLE       hDevice,            // @parm A handle to a POTS line device.
  IN OTX_INT32        nDelayCnt,          // @parm Number of millisecond tick for pulse width.
  OUT OTX_UINT32     *slicState           // @parm current OtxSlicDeviceCallState
);


/*******************************************************************************

  @func
    Enable Slic Audio Path for the device.

  @ex |
    result = OtxSlicStopRingState( g_hPhysDevs.hSlicLi[deviceNumber], 
                                    &slicState );
    DemoCheckRc(g_hPhysDevs.hSlicLi[deviceNumber], result);

*******************************************************************************/
OTX_EXPORT OTX_RESULT OTX_API OtxSlicEnableAudio(
  IN OTX_HANDLE       hDevice,            // @parm A handle to a POTS line device.
  OUT OTX_UINT32     *slicState           // @parm current OtxSlicDeviceCallState
);


/*******************************************************************************

  @func
    Set User field in caller ID data string for the device.

  @comm
    This function only needs to be called when the user name within the 
    caller ID field needs to be modified. This is usually only peformed when
    the appliction data is being initialized. But can be modified anytime.

  @ex |
    

*******************************************************************************/
OTX_EXPORT OTX_RESULT OTX_API OtxSlicSetUserName(
  IN OTX_HANDLE       hDevice,            // @parm A handle to a POTS line device.
  IN OTX_UINT8       *userName,           // @parm pointer to ASCII string containing the users name
  OUT OTX_UINT32     *slicState           // @parm current OtxSlicDeviceCallState
);

/*******************************************************************************

  @func
    Set phone number field in caller ID data string for the device.

  @comm
    This function only needs to be called when the phone number within the 
    caller ID field needs to be modified. This is usually only peformed when
    the appliction data is being initialized. But can be modified anytime.

  @ex |
    

*******************************************************************************/
OTX_EXPORT OTX_RESULT OTX_API OtxSlicSetPhoneNumber(
  IN OTX_HANDLE       hDevice,            // @parm A handle to a POTS line device.
  IN OTX_UINT8       *phoneNumber,        // @parm pointer to ASCII string containing the phone number
  OUT OTX_UINT32     *slicState           // @parm current OtxSlicDeviceCallState
);

/*******************************************************************************

  @func
    Send caller ID setup for the device.

  @comm
    This function setup and starts the caller ID process. The sending of the 
    caller ID takes several interrupt cycles to complete. This call will return
    before the process of sending the caller ID has completed.

  @ex |
    

*******************************************************************************/
OTX_EXPORT OTX_RESULT OTX_API OtxSlicSendCallerID(
  IN OTX_HANDLE       hDevice,           // @parm A handle to a POTS line device.
  OUT OTX_UINT32     *slicState          // @parm current OtxSlicDeviceCallState
);




#ifdef __cplusplus
}  // extern "C"
#endif

/*******************************************************************************

  Copyright (C) Odin TeleSystems Inc., 2005


  All rights reserved. No part of this computer program may be reproduced,
  stored in any retrieval system, or transmitted, in any form or by any
  means, electronic, mechanical, photocopying, recording, or otherwise,
  without the prior written permission of Odin TeleSystems Inc., or without
  a permission stipulated in the agreement/contract under which this computer
  program was supplied.

*******************************************************************************/
#endif  // OTX_SLIC_H
