/* $Workfile: OtxTemuxD.h $   $Revision: 3 $    $Modtime: 3/19/10 10:08a $  */
#ifndef OTX_TEMUX_DEF_H
#define OTX_TEMUX_DEF_H
/*******************************************************************************

  @doc PublicHwApi OtxTemuxD

  Copyright (C) 2010 Odin TeleSystems Inc., All Rights Reserved

  OTX Generic Hardware Driver API

  @module
  OtxTemuxD | Constants, Macros, and Types for the Temux SONET/SDH Functions

  @contents2
  OtxTemuxD.h |

  @index const enum struct type | OtxTemuxD

  @contents2
  OTX Temux SONET/SDH Device Constants, Macros, and Types |

  @head3 Enumerated Types  |

  @index enum | OtxTemuxD

  @head3 Struct Types |

  @index struct | OtxTemuxD

  @head3 Constants |

  @index const | OtxTemuxD

  @head3 Other Types |

  @index type | OtxTemuxD

*******************************************************************************/

#ifdef __cplusplus
extern "C" {
#endif

#define OTX_TEMUX_MAX_LINK     4 // Temux supports up to 4 SONET/SDH links
#define OTX_TEMUX_MAX_STS1     3 // Temux supports up to 3 STS1
#define OTX_TEMUX_MAX_VTGROUP  7 // Temux supports up to 7 VT Group
#define OTX_TEMUX_MAX_TRIB    28 // Temux supports up to 28 tributaries
#define OTX_TEMUX_T1_TRIB     28 // Temux supports up to 28 T1 tributaries
#define OTX_TEMUX_E1_TRIB     21 // Temux supports up to 21 E1 tributaries

/*******************************************************************************
  @enum
    Event Codes

    Note that for line interfaces messages can have a different meaning 
    depending on whether the Line Interfaces (LIs) are configured to E1 
    or T1 mode and have seperate events.

*******************************************************************************/
enum OtxTemuxEventCodesE {
  OTX_TEMUX_EC_ING_LI_LOS,  // @emem SONET(SDH) LOS
  OTX_TEMUX_EC_ING_LI_LOF,  // @emem SONET(SDH) LOF
  OTX_TEMUX_EC_ING_LI_TIM,  // @emem SONET(SDH) Trace identifier mismatch
  OTX_TEMUX_EC_ING_LI_SF,   // @emem SONET(SDH) Signal Failure
  OTX_TEMUX_EC_ING_LI_SD,   // @emem SONET(SDH) Signal Degrade
  OTX_TEMUX_EC_ING_LI_LAIS, // @emem SONET(SDH) Alarm indication signal
  OTX_TEMUX_EC_HOPP_TIM,    // @emem SONET(SDH) 
  OTX_TEMUX_EC_HOPP_TIU,    // @emem SONET(SDH) 
  OTX_TEMUX_EC_HOPP_PERDI,  // @emem SONET(SDH) 
  OTX_TEMUX_EC_HOPP_PRDI,   // @emem SONET(SDH) 
  OTX_TEMUX_EC_HOPP_PPDI,   // @emem SONET(SDH) 
  OTX_TEMUX_EC_HOPP_PUNEQ,  // @emem SONET(SDH) 
  OTX_TEMUX_EC_HOPP_PPLM,   // @emem SONET(SDH) 
  OTX_TEMUX_EC_HOPP_PPLU,   // @emem SONET(SDH) 
  OTX_TEMUX_EC_HOPP_SF,     // @emem SONET(SDH) 
  OTX_TEMUX_EC_HOPP_SD,     // @emem SONET(SDH) 
  OTX_TEMUX_EC_SPE_PAISC,   // @emem SONET(SDH) 
  OTX_TEMUX_EC_SPE_PLOPC,   // @emem SONET(SDH) 
  OTX_TEMUX_EC_SPE_PAIS,    // @emem SONET(SDH) 
  OTX_TEMUX_EC_SPE_PLOP,    // @emem SONET(SDH) 
  OTX_TEMUX_EC_TRIB_LOM,    // @emem SONET(SDH) Tributary
  OTX_TEMUX_EC_TRIB_AIS,    // @emem SONET(SDH) Tributary
  OTX_TEMUX_EC_TRIB_LOP,    // @emem SONET(SDH) Tributary
  OTX_TEMUX_EC_TRIB_RDI,    // @emem SONET(SDH) Tributary
  OTX_TEMUX_EC_TRIB_ERDI,   // @emem SONET(SDH) Tributary
  OTX_TEMUX_EC_TRIB_PSLU,   // @emem SONET(SDH) Tributary
  OTX_TEMUX_EC_TRIB_PSLM,   // @emem SONET(SDH) Tributary
  OTX_TEMUX_EC_TRIB_UNEQ,   // @emem SONET(SDH) Tributary
  OTX_TEMUX_EC_TRIB_PDI,    // @emem SONET(SDH) Tributary
  OTX_TEMUX_EC_TRIB_TIM,    // @emem SONET(SDH) Tributary
  OTX_TEMUX_EC_TRIB_TIU,    // @emem SONET(SDH) Tributary
  OTX_TEMUX_EC_TRIB_SF,     // @emem SONET(SDH) Tributary
  OTX_TEMUX_EC_TRIB_SD,     // @emem SONET(SDH) Tributary
  OTX_TEMUX_EC_T1_AIS,      // @emem PDH DS1
  OTX_TEMUX_EC_T1_RED,      // @emem PDH DS1
  OTX_TEMUX_EC_T1_YEL,      // @emem PDH DS1
  OTX_TEMUX_EC_T1_COFA,     // @emem PDH DS1
  OTX_TEMUX_EC_T1_INF,      // @emem PDH DS1
  OTX_TEMUX_EC_E1_TS16AISD, // @emem PDH DS1
  OTX_TEMUX_EC_E1_AIS,      // @emem PDH DS1
  OTX_TEMUX_EC_E1_RED,      // @emem PDH DS1
  OTX_TEMUX_EC_E1_AISD,     // @emem PDH DS1
  OTX_TEMUX_EC_E1_RMAI,     // @emem PDH DS1
  OTX_TEMUX_EC_E1_RAI,      // @emem PDH DS1
  OTX_TEMUX_EC_E1_CFEBE,    // @emem PDH DS1
  OTX_TEMUX_EC_E1_RAICCRC,  // @emem PDH DS1
  OTX_TEMUX_EC_E1_OOOF,     // @emem PDH DS1
  OTX_TEMUX_EC_E1_INCMF,    // @emem PDH DS1
  OTX_TEMUX_EC_E1_INSMF,    // @emem PDH DS1 
  OTX_TEMUX_EC_E1_INF,      // @emem PDH DS1
  OTX_TEMUX_EC_DS3_RED,     // @emem PDH 
  OTX_TEMUX_EC_DS3_CBIT,    // @emem PDH 
  OTX_TEMUX_EC_DS3_RDI,     // @emem PDH 
  OTX_TEMUX_EC_DS3_IDL,     // @emem PDH 
  OTX_TEMUX_EC_DS3_AIS,     // @emem PDH 
  OTX_TEMUX_EC_DS3_OOF,     // @emem PDH 
  OTX_TEMUX_EC_DS3_LOS,     // @emem PDH 
  OTX_TEMUX_EC_DS3_LOF,     // @emem PDH 
  OTX_TEMUX_EC_E3_LOS,      // @emem PDH 
  OTX_TEMUX_EC_E3_OOF,      // @emem PDH 
  OTX_TEMUX_EC_E3_RDI_RAI,  // @emem PDH 
  OTX_TEMUX_EC_E3_REI,      // @emem PDH 
  OTX_TEMUX_EC_E3_PTYPE0,   // @emem PDH 
  OTX_TEMUX_EC_E3_PTYPE1,   // @emem PDH 
  OTX_TEMUX_EC_E3_PTYPE2,   // @emem PDH 
  OTX_TEMUX_EC_E3_TIMEMK,   // @emem PDH 
  OTX_TEMUX_EC_E3_NETUSE,   // @emem PDH 
  OTX_TEMUX_EC_E3_LOF,      // @emem PDH 
  OTX_TEMUX_EC_E3_AIS,      // @emem PDH 
  OTX_TEMUX_EC_M13_RED,     // @emem PDH 
  OTX_TEMUX_EC_M13_FERF,    // @emem PDH 
  OTX_TEMUX_EC_M13_RES,     // @emem PDH 
  OTX_TEMUX_EC_M13_AIS,     // @emem PDH 
  OTX_TEMUX_EC_M13_OOF      // @emem PDH 

};
typedef enum OtxTemuxEventCodesE OtxTemuxEventCodesE;

/*******************************************************************************
  @enum 
    Temux interface 
*******************************************************************************/
enum OtxTemuxInterfaceE {
  OTX_TEMUX_INTERFACE_SBI    = 0,  // @emem SBI interface
  OTX_TEMUX_INTERFACE_HMVIP  = 1   // @emem HMVIP interface
};
typedef enum OtxTemuxInterfaceE OtxTemuxInterfaceE;

/*******************************************************************************
  @enum 
    Temux device configuration setup used to configure the entire device.
    Configuration option 0 is for user defined configuration.

  @xref
    <f OtxTemuxDeviceCfg>

*******************************************************************************/
enum OtxTemuxDevConfigureE {
  OTX_TEMUX_DEVICE_DEFAULT = 1,    // @emem 4 x OC-3 Working Links - Internally timed
                                   // <nl> Each OC-3 has the following mapping:
                                   // <nl> OC-3 >> STS-3 >> 3 x STS-1
                                   // <nl> Each STS-1 has the following mapping:
                                   // <nl> STS-1 >> 7 x VT-Group
                                   // <nl> Each VT-Group has the following mapping:
                                   // <nl> VT-Group >> 4 x VT-1.5
                                   // <nl> Each VT-1.5 contains a bit asynchronously mapped T1
                                   // <nl> Each T1 has ESF framing format and is loop timed to CTCLK

  OTX_TEMUX_DS3M13CFG ,            // @emem 12 DS3 Links - Internally timed
                                   // <nl> Each DS3 has the following multiplexing:
                                   // <nl> C Bit DS3 >> M13 >> 28 ESF T1
                                   // <nl> Each T1 has ESF framing format.
                                   // <nl> For SBI System Interface, T1 tributaries are loop timed.
                                   // <nl> For HMVIP System Interface, T1 tributaries are internally
                                   // timed to CTCLK.

  OTX_TEMUX_T1VT15STS3CFG ,        // @emem 4 x OC-3 Working Links - Internally timed
                                   // <nl> Each OC-3 has the following mapping:
                                   // <nl> OC-3 >> STS-3 >> 3 x STS-1
                                   // <nl> Each STS-1 has the following mapping:
                                   // <nl> STS-1 >> 7 x VT-Group
                                   // <nl> Each VT-Group has the following mapping:
                                   // <nl> VT-Group >> 4 x VT-1.5
                                   // <nl> Each VT-1.5 contains a bit asynchronously mapped T1
                                   // <nl> Each T1 has ESF framing format.
                                   // <nl> For SBI System Interface, T1 tributaries are loop timed.
                                   // <nl> For HMVIP System Interface, T1 tributaries are internally 
                                   // timed to CTCLK.

  OTX_TEMUX_T1VT2STS3CFG ,         // @emem 4 x OC-3 Working Links - Internally timed
                                   // <nl> Each OC-3 has the following mapping:
                                   // <nl> OC-3 >> STS-3 >> 3 x STS-1
                                   // <nl> Each STS-1 has the following mapping:
                                   // <nl> STS-1 >> 7 x VT-Group
                                   // <nl> Each VT-Group has the following mapping:
                                   // <nl> VT-Group >> 3 x VT-2
                                   // <nl> Each VT-2 contains a bit asynchronously mapped T1
                                   // <nl> Each T1 has ESF framing format.
                                   // <nl> For SBI System Interface, T1 tributaries are loop timed.
                                   // <nl> For HMVIP System Interface, T1 tributaries are internally
                                   // timed to CTCLK.

  OTX_TEMUX_E1VT2STS3CFG ,         // @emem 4 x OC-3 Working Links - Internally timed
                                   // <nl> Each OC-3 has the following mapping:
                                   // <nl> OC-3 >> STS-3 >> 3 x STS-1
                                   // <nl> Each STS-1 has the following mapping:
                                   // <nl> STS-1 >> 7 x VT-Group
                                   // <nl> Each VT-Group has the following mapping:
                                   // <nl> VT-Group >> 3 x VT-2
                                   // <nl> Each VT-2 contains a bit asynchronously mapped E1
                                   // <nl> Each E1 has Standard framing format.
                                   // <nl> For SBI System Interface, E1 tributaries are loop timed.
                                   // <nl> For HMVIP System Interface, E1 tributaries are internally
                                   // timed to CTCLK.

  OTX_TEMUX_DS3G747CFG ,           // @emem 12 DS3 Links - Internally timed
                                   // <nl> Each DS3 has the following multiplexing:
                                   // <nl> C Bit DS3 >> M13 >> 21 Standard E1
                                   // <nl> Each E1 has Standard framing format.
                                   // <nl> For SBI System Interface, E1 tributaries are loop timed.
                                   // <nl> For HMVIP System Interface, E1 tributaries are internally
                                   // timed to CTCLK.

  OTX_TEMUX_T1TU11AU4STM1CFG ,     // @emem 4 x STM-1 Working Links - Internally timed
                                   // <nl> Each STM-1 has the following mapping:
                                   // <nl> STM-1 >> AUG-1 >> 1 x AU-4
                                   // <nl> Each AU-4 has the following mapping:
                                   // <nl> AU-4 >> 3 x TUG-3
                                   // <nl> Each TUG-3 has the following mapping:
                                   // <nl> TUG-3 >> 7 x TUG-2
                                   // <nl> Each TUG-2 has the following mapping:
                                   // <nl> TUG-2 >> 4 x TU-11
                                   // <nl> Each TU-11 contains a bit asynchronously mapped T1
                                   // <nl> Each T1 has ESF framing format.
                                   // <nl> For SBI System Interface, T1 tributaries are loop timed.
                                   // <nl> For HMVIP System Interface, T1 tributaries are internally
                                   // timed to CTCLK.

  OTX_TEMUX_T1TU12AU4STM1CFG ,     // @emem 4 x STM-1 Working Links - Internally timed
                                   // <nl> Each STM-1 has the following mapping:
                                   // <nl> STM-1 >> AUG-1 >> 1 x AU-4
                                   // <nl> Each AU-4 has the following mapping:
                                   // <nl> AU-4 >> 3 x TUG-3
                                   // <nl> Each TUG-3 has the following mapping:
                                   // <nl> TUG-3 >> 7 x TUG-2
                                   // <nl> Each TUG-2 has the following mapping:
                                   // <nl> TUG-2 >> 3 x TU-12
                                   // <nl> Each TU-12 contains a bit asynchronously mapped T1
                                   // <nl> Each T1 has ESF framing format.
                                   // <nl> For SBI System Interface, T1 tributaries are loop timed.
                                   // <nl> For HMVIP System Interface, T1 tributaries are internally
                                   // timed to CTCLK.

  OTX_TEMUX_E1TU12AU4STM1CFG ,     // @emem 4 x STM-1 Working Links - Internally timed
                                   // <nl> Each STM-1 has the following mapping:
                                   // <nl> STM-1 >> AUG-1 >> 1 x AU-4
                                   // <nl> Each AU-4 has the following mapping:
                                   // <nl> AU-4 >> 3 x TUG-3
                                   // <nl> Each TUG-3 has the following mapping:
                                   // <nl> TUG-3 >> 7 x TUG-2
                                   // <nl> Each TUG-2 has the following mapping:
                                   // <nl> TUG-2 >> 3 x TU-12
                                   // <nl> Each TU-12 contains a bit asynchronously mapped E1
                                   // <nl> Each E1 has Standard framing format.
                                   // <nl> For SBI System Interface, E1 tributaries are loop timed.
                                   // <nl> For HMVIP System Interface, E1 tributaries are internally
                                   // timed to CTCLK.

  OTX_TEMUX_T1TU11AU3STM1CFG ,     // @emem 4 x STM-1 Working Links - Internally timed
                                   // <nl> Each STM-1 has the following mapping:
                                   // <nl> STM-1 >> AUG-1 >> 3 x AU-3
                                   // <nl> Each AU-3 has the following mapping:
                                   // <nl> AU-3 >> 7 x TUG-2
                                   // <nl> Each TUG-2 has the following mapping:
                                   // <nl> TUG-2 >> 4 x TU-11
                                   // <nl> Each TU-11 contains a bit asynchronously mapped T1
                                   // <nl> Each T1 has ESF framing format.
                                   // <nl> For SBI System Interface, T1 tributaries are loop timed.
                                   // <nl> For HMVIP System Interface, T1 tributaries are internally
                                   // timed to CTCLK.

  OTX_TEMUX_T1TU12AU3STM1CFG ,     // @emem 4 x STM-1 Working Links - Internally timed
                                   // <nl> Each STM-1 has the following mapping:
                                   // <nl> STM-1 >> AUG-1 >> 3 x AU-3
                                   // <nl> Each AU-3 has the following mapping:
                                   // <nl> AU-3 >> 7 x TUG-2
                                   // <nl> Each TUG-2 has the following mapping:
                                   // <nl> TUG-2 >> 3 x TU-12
                                   // <nl> Each TU-12 contains a bit asynchronously mapped T1
                                   // <nl> Each T1 has ESF framing format.
                                   // <nl> For SBI System Interface, T1 tributaries are loop timed.
                                   // <nl> For HMVIP System Interface, T1 tributaries are internally
                                   // timed to CTCLK.

  OTX_TEMUX_E1TU12AU3STM1CFG ,     // @emem 4 x STM-1 Working Links - Internally timed
                                   // <nl> Each STM-1 has the following mapping:
                                   // <nl> STM-1 >> AUG-1 >> 3 x AU-3
                                   // <nl> Each AU-3 has the following mapping:
                                   // <nl> AU-3 >> 7 x TUG-2
                                   // <nl> Each TUG-2 has the following mapping:
                                   // <nl> TUG-2 >> 3 x TU-12
                                   // <nl> Each TU-12 contains a bit asynchronously mapped E1
                                   // <nl> Each E1 has Standard framing format.
                                   // <nl> For SBI System Interface, E1 tributaries are loop timed.
                                   // <nl> For HMVIP System Interface, E1 tributaries are internally
                                   // timed to CTCLK.

  OTX_TEMUX_T1TU11AU3STM4CFG ,     // @emem 1 x STM-4 Working Links - Internally timed
                                   // <nl> Each STM-4 has the following mapping:
                                   // <nl> STM-4 >> 4 x AUG-1 >> 3 x AU-3
                                   // <nl> Each AU-3 has the following mapping:
                                   // <nl> AU-3 >> 7 x TUG-2
                                   // <nl> Each TUG-2 has the following mapping:
                                   // <nl> TUG-2 >> 4 x TU-11
                                   // <nl> Each TU-11 contains a bit asynchronously mapped T1
                                   // <nl> Each T1 has unframed framing format.
                                   // <nl> For SBI System Interface, Timing Information for T1
                                   // <nl> tributaries are from the System Side Interface.
                                   // <nl> For HMVIP System Interface, T1 tributaries are internally
                                   // <nl> timed to CTCLK.

  OTX_TEMUX_E1TU12AU4STM4CFG ,     // @emem 1 x STM-4 Working Links - Internally timed
                                   // <nl> Each STM-4 has the following mapping:
                                   // <nl> STM-4 >> 4 x AUG-1 >> 1 x AU-4
                                   // <nl> Each AU-4 has the following mapping:
                                   // <nl> AU-4 >> 3 x TUG-3
                                   // <nl> Each TUG-3 has the following mapping:
                                   // <nl> TUG-3 >> 7 x TUG-2
                                   // <nl> Each TUG-2 has the following mapping:
                                   // <nl> TUG-2 >> 3 x TU-12
                                   // <nl> Each TU-12 contains a bit asynchronously mapped E1
                                   // <nl> Each E1 has unframed framing format.
                                   // <nl> For SBI System Interface, Timing Information for E1
                                   // <nl> tributaries are from the System Side Interface.
                                   // <nl> For HMVIP System Interface, E1 tributaries are internally
                                   // <nl> timed to CTCLK.

  OTX_TEMUX_T1TU11AU4STM4CFG ,     // @emem 1 x STM-4 Working Links - Internally timed
                                   // <nl> Each STM-4 has the following mapping:
                                   // <nl> STM-4 >> 4 x AUG-1 >> 1 x AU-4
                                   // <nl> Each AU-4 has the following mapping:
                                   // <nl> AU-4 >> 3 x TUG-3
                                   // <nl> Each TUG-3 has the following mapping:
                                   // <nl> TUG-3 >> 7 x TUG-2
                                   // <nl> Each TUG-2 has the following mapping:
                                   // <nl> TUG-2 >> 4 x TU-11
                                   // <nl> Each TU-11 contains a bit asynchronously mapped T1
                                   // <nl> Each T1 has ESF framing format.
                                   // <nl> For SBI System Interface, T1 tributaries are loop timed.
                                   // <nl> For HMVIP System Interface, T1 tributaries are internally
                                   // timed to CTCLK.

  OTX_TEMUX_DS3UNCHANNELIZEDCFG ,  // @emem 12 DS3 Links - Flow through timing 
                                   // <nl> using link rate data from SBI system 
                                   // <nl> interface. Each DS3 has C bit framing
                                   // <nl> System side interface is SBI Bus

  OTX_TEMUX_DS3M13AU4STM1CFG ,     // @emem 4 x STM-1 Working Links - Internally timed
                                   // <nl> Each STM-1 has the following mapping:
                                   // <nl> STM-1 >> AUG-1 >> 1 x AU-4
                                   // <nl> Each AU-4 has the following mapping:
                                   // <nl> AU-4 >> 3 x TUG-3
                                   // <nl> Each TUG-3 has the following mapping:
                                   // <nl> TUG-3 >> TU-3 >> VC-3 >> C3
                                   // <nl> Each C3 has DS3 payload.
                                   // <nl> Each DS3 has the following multiplexing:
                                   // <nl> C Bit DS3 >> M13 >> 28 ESF T1
                                   // <nl> Each T1 has ESF framing format.
                                   // <nl> For SBI System Interface, T1 
                                   // <nl> tributaries are loop timed.
                                   // <nl> For HMVIP System Interface, 
                                   // <nl> T1 tributaries are internally
                                   // <nl> timed to CTCLK.

  OTX_TEMUX_DS3M13AU3STM1CFG ,     // @emem 4 x STM-1 Working Links - Internally timed
                                   // <nl> Each STM-1 has the following mapping:
                                   // <nl> STM-1 >> AUG-1 >> 3 x AU-3
                                   // <nl> Each AU-3 has the following mapping:
                                   // <nl> AU-3 >> C-3
                                   // <nl> Each C3 has DS3 payload.
                                   // <nl> Each DS3 has the following multiplexing:
                                   // <nl> C Bit DS3 >> M13 >> 28 ESF T1
                                   // <nl> Each T1 has ESF framing format.
                                   // <nl> For SBI System Interface, T1 
                                   // <nl> tributaries are loop timed. For 
                                   // <nl> HMVIP System Interface, T1 tributaries 
                                   // <nl> are internally timed to CTCLK.

  OTX_TEMUX_DS3UNCHAU3STM1CFG ,    // @emem 4 x STM-1 Working Links - Internally timed
                                   // <nl> Each STM-1 has the following mapping:
                                   // <nl> STM-1 >> AUG-1 >> 3 x AU-3
                                   // <nl> Each AU-3 has the following mapping:
                                   // <nl> AU-3 >> C-3
                                   // <nl> Each C3 has DS3 payload.
                                   // <nl> Each DS3 Uses - Flow through timing 
                                   // <nl> using link rate data from SBI system 
                                   // <nl> interface. Each DS3 has C bit framing
                                   // <nl> System side interface is SBI Bus

  OTX_TEMUX_T1VT15STS3LPTIMINGCFG // @emem 4 x OC-3 Working Links - Loop timed
                                  // <nl> Each OC-3 has the following mapping:
                                  // <nl>    OC-3 >> STS-3 >> 3 x STS-1
                                  // <nl> Each STS-1 has the following mapping:
                                  // <nl>    STS-1 >> 7 x VT-Group
                                  // <nl> Each VT-Group has the following mapping:
                                  // <nl>    VT-Group >> 4 x VT-1.5
                                  // <nl> Each VT-1.5 contains a bit asynchronously 
                                  // <nl> mapped T1 each T1 has ESF framing format.
                                  // <nl> For SBI System Interface, T1 tributaries 
                                  // <nl> are loop timed. For HMVIP System Interface, 
                                  // <nl> T1 tributaries are internally timed to CTCLK. 

};
typedef enum OtxTemuxDevConfigureE OtxTemuxDevConfigureE;

/******************************************************************************
  @enum 
    Temux SONET/SDH subsystem configuration for used to set the link to the
    OC-12/STM-4 payload is concatenated (sts12Concatenation) and an OC-3/STM-1
    or STS-3/AUG-1 payload is concatenated (sts3Concatenation).

  @xref
    <f OtxTemuxSonetPayloadCfg>
    <t OtxTemuxSts12Concat>

******************************************************************************/
enum OtxTemuxSts3Concat {
  OTX_TEMUX_3_STS1  = 0,  // @emem 3 x STS-1/AU-3
  OTX_TEMUX_STS3    = 1   // @emem STS-3c/AU4
};
typedef enum OtxTemuxSts3Concat OtxTemuxSts3Concat;

/******************************************************************************
  @enum 
    Temux SONET/SDH subsystem configuration for used to set the link to the
    OC-12/STM-4 payload is concatenated (sts12Concatenation) and an OC-3/STM-1
    or STS-3/AUG-1 payload is concatenated (sts3Concatenation).

  @xref
    <f OtxTemuxSonetPayloadCfg>
    <t OtxTemuxSts3Concat>

******************************************************************************/
enum OtxTemuxSts12Concat {
  OTX_TEMUX_4_STS3  = 0,  // @emem 4 x STS-3/AUG-1
  OTX_TEMUX_STS12   = 1   // @emem STS-12c/AU4-4c
};
typedef enum OtxTemuxSts12Concat OtxTemuxSts12Concat;

/*******************************************************************************
  @enum 
    Temux SONET/SDH subsystem configuration destination port

  @xref
    <f OtxTemuxStsiDestPortCfg>

*******************************************************************************/
enum OtxTemuxDestPortE {
  OTX_TEMUX_DEST_PORT_HOPP    = 0,  // @emem HOPP Receive
  OTX_TEMUX_DEST_PORT_ESSI_W  = 1,  // @emem ESSI Working Transmit
  OTX_TEMUX_DEST_PORT_ESSI_P  = 2,  // @emem ESSI Protect Transmit
  OTX_TEMUX_DEST_PORT_OC3_12  = 3   // @emem 4 x OC-3 or OC-12 Transmit
};
typedef enum OtxTemuxDestPortE OtxTemuxDestPortE;


/*******************************************************************************
  @enum 
    Temux SONET/SDH subsystem configuration source port.
      STSI timeslots used for each STS-3
    
      0xA0 - timeslot 1, 5, 9
      0xA1 - timeslot 2, 6, 10
      0xA2 - timeslot 3, 7, 11
      0xA3 - timeslot 4, 8, 12
    
      where A is the STSI number

  @xref
    <f OtxTemuxStsiDestPortCfg>

*******************************************************************************/
enum OtxTemuxSrcPortE {
  OTX_TEMUX_SRC_OC3_00    = 0x00, // @emem Rx OC-3 #1/Rx OC-12 STS-3 #1
  OTX_TEMUX_SRC_OC3_01    = 0x01, // @emem Rx OC-3 #2/Rx OC-12 STS-3 #2
  OTX_TEMUX_SRC_OC3_02    = 0x02, // @emem Rx OC-3 #3/Rx OC-12 STS-3 #3
  OTX_TEMUX_SRC_OC3_03    = 0x03, // @emem Rx OC-3 #4/Rx OC-12 STS-3 #4
  OTX_TEMUX_SRC_ESSI_10    = 0x10, // @emem Rx ESSI Work STS-3 #1
  OTX_TEMUX_SRC_ESSI_11    = 0x11, // @emem Rx ESSI Work STS-3 #2
  OTX_TEMUX_SRC_ESSI_12    = 0x12, // @emem Rx ESSI Work STS-3 #3
  OTX_TEMUX_SRC_ESSI_13    = 0x13, // @emem Rx ESSI Work STS-3 #4
  OTX_TEMUX_SRC_ESSI_20    = 0x20, // @emem Rx ESSI Protect STS-3 #1
  OTX_TEMUX_SRC_ESSI_21    = 0x21, // @emem Rx ESSI Protect STS-3 #2
  OTX_TEMUX_SRC_ESSI_22    = 0x22, // @emem Rx ESSI Protect STS-3 #3
  OTX_TEMUX_SRC_ESSI_23    = 0x23, // @emem Rx ESSI Protect STS-3 #4
  OTX_TEMUX_SRC_HOPP_30    = 0x30, // @emem Tx HOPP STS-3 #1
  OTX_TEMUX_SRC_HOPP_31    = 0x31, // @emem Tx HOPP STS-3 #2
  OTX_TEMUX_SRC_HOPP_32    = 0x32, // @emem Tx HOPP STS-3 #3
  OTX_TEMUX_SRC_HOPP_33    = 0x33  // @emem Tx HOPP STS-3 #4
};
typedef enum OtxTemuxSrcPortE OtxTemuxSrcPortE;

/*******************************************************************************
  @enum 
    Temux SONET/SDH subsystem configuration MSU telecombus switching type

  @xref
    <f OtxTemuxMsuCfg>

*******************************************************************************/
enum OtxTemuxBlockTypeE {
  OTX_TEMUX_MSU_TYPE_RMSU    = 0, // @emem RMSU
  OTX_TEMUX_MSU_TYPE_TMSU    = 1  // @emem TMSU
};
typedef enum OtxTemuxBlockTypeE OtxTemuxBlockTypeE;

/*******************************************************************************
  @enum 
    Temux SONET/SDH subsystem configuration MSU telecombus switching mode

  @xref
    <f OtxTemuxMsuCfg>

*******************************************************************************/
enum OtxTemuxBlockModeE {
  OTX_TEMUX_MSU_MODE_SWITCH  = 0, // @emem Telecombus switching
  OTX_TEMUX_MSU_MODE_BYPASS  = 1  // @emem Bypass
};
typedef enum OtxTemuxBlockModeE OtxTemuxBlockModeE;

/*******************************************************************************
  @enum 
    Temux SONET/SDH subsystem configuration physical interface used

  @xref
    <f OtxTemuxSonetIntfCfg>

*******************************************************************************/
enum OtxTemuxIntfModeE {
  OTX_TEMUX_INTF_MODE_OC3_STM1    = 0, // @emem up to 4 x OC-3/STM-1
  OTX_TEMUX_INTF_MODE_1_OC12_STM4 = 1  // @emem one OC-12/STM-4
};
typedef enum OtxTemuxIntfModeE OtxTemuxIntfModeE;

/*******************************************************************************
  @enum 
    Temux SONET/SDH subsystem configuration link source

  @xref
    <f OtxTemuxSonetLinkCfg>

*******************************************************************************/
enum OtxTemuxLinkSrcE {
  OTX_TEMUX_LINK_WORKING  = 0, // @emem Working
  OTX_TEMUX_LINK_PROTECT  = 1  // @emem Protect
};
typedef enum OtxTemuxLinkSrcE OtxTemuxLinkSrcE;

/*******************************************************************************
  @enum 
    Temux SONET/SDH subsystem configuration link source

  @xref
    <f OtxTemuxSonetDataPathCfg>

*******************************************************************************/
enum OtxTemuxDataLinkSrcE {
  OTX_TEMUX_DATALINK_PROTECT  = 0, // @emem Protect
  OTX_TEMUX_DATALINK_WORKING  = 1  // @emem Working
};
typedef enum OtxTemuxDataLinkSrcE OtxTemuxDataLinkSrcE;

/******************************************************************************
  @enum 
    Temux SONET/SDH subsystem configuration link clock source

    The internal link clock source is defined by <f OtxBrdSetClocks>) 
    board clock source provided for the Temux device.


  @xref
    <f OtxTemuxSonetTimingCfg>

******************************************************************************/
enum OtxTemuxClockSrcE {
  OTX_TEMUX_CLOCK_INTERNAL = 0,   // @emem Link internal timing
  OTX_TEMUX_CLOCK_LOOP     = 1    // @emem Link loop timing
};
typedef enum OtxTemuxClockSrcE OtxTemuxClockSrcE;

/******************************************************************************
  @enum 
    Temux SONET/SDH subsystem configuration for STS-12 payload

  @xref
    <f OtxTemuxSts12PayloadCfg>

******************************************************************************/
enum OtxTemuxSts12PayloadE {
  OTX_TEMUX_STS_12   = 0,   // @emem STS-12c/AU4-4c
  OTX_TEMUX_4_STS_3  = 1    // @emem Four x STS-3/AUG-1
};
typedef enum OtxTemuxSts12PayloadE OtxTemuxSts12PayloadE;

/******************************************************************************
  @enum 
    Temux SONET/SDH subsystem configuration for STS-3 payload

  @xref
    <f OtxTemuxSts3PayloadCfg>

******************************************************************************/
enum OtxTemuxSts3PayloadE {
  OTX_TEMUX_STS_3   = 0,   // @emem STS-3c/AU-4
  OTX_TEMUX_3_STS_1 = 1    // @emem Three x STS-1/AU-3
};
typedef enum OtxTemuxSts3PayloadE OtxTemuxSts3PayloadE;

/******************************************************************************
  @enum 
    Temux SONET/SDH subsystem configuration for STS-3C payload

  @xref
    <f OtxTemuxSts3cPayloadCfg>

******************************************************************************/
enum OtxTemuxSts3cPayloadE {
  OTX_TEMUX_STS_3C   = 0,   // @emem C-4
  OTX_TEMUX_3C_STS_1 = 1    // @emem Three x TUG-3
};
typedef enum OtxTemuxSts3cPayloadE OtxTemuxSts3cPayloadE;

/******************************************************************************
  @enum 
    Temux SONET/SDH subsystem configuration for STS-1 payload

  @xref
    <f OtxTemuxSts1PayloadCfg>

******************************************************************************/
enum OtxTemuxSts1PayloadE {
  OTX_TEMUX_STS_1      = 0,   // @emem C-3
  OTX_TEMUX_7_VT_GROUP = 1    // @emem Seven x VT-Group
};
typedef enum OtxTemuxSts1PayloadE OtxTemuxSts1PayloadE;

/******************************************************************************
  @enum 
    Temux SONET/SDH subsystem configuration for TUG-3 payload

  @xref
    <f OtxTemuxTug3PayloadCfg>

******************************************************************************/
enum OtxTemuxTug3PayloadE {
  OTX_TEMUX_TU_3      = 0,   // @emem TU-3 demapped to C-3
  OTX_TEMUX_7_TUG_2   = 1    // @emem Seven x TUG-2
};
typedef enum OtxTemuxTug3PayloadE OtxTemuxTug3PayloadE;

/******************************************************************************
  @enum 
    Temux SONET/SDH subsystem configuration for TUG-2 payload

  @xref
    <f OtxTemuxTug2PayloadCfg>

******************************************************************************/
enum OtxTemuxTug2PayloadE {
  OTX_TEMUX_TU_12      = 0,   // @emem TU-12
  OTX_TEMUX_TU_11      = 1    // @emem TU-11
};
typedef enum OtxTemuxTug2PayloadE OtxTemuxTug2PayloadE;

/******************************************************************************
  @enum 
    Temux SONET/SDH subsystem configuration for 
    VT-Group payload, virtual tributaries (VT)

  @xref
    <f OtxTemuxVtGroupPayloadCfg>
    <f OtxTemuxMapperTribCfg>

******************************************************************************/
enum OtxTemuxVtTypeE {
  OTX_TEMUX_VT_2       = 0,   // @emem VT-2   E1
  OTX_TEMUX_VT_15      = 1    // @emem VT-1.5 T1
};
typedef enum OtxTemuxVtTypeE OtxTemuxVtTypeE;

/******************************************************************************
  @enum 
    Temux SONET/SDH subsystem configuration for TVPTA bypassing

  @xref
    <f OtxTemuxTvtpaBypassCfg>

******************************************************************************/
enum OtxTemuxBypassE {
  OTX_TEMUX_BYPASSED      = 0,   // @emem bypassed 
  OTX_TEMUX_NOT_BYPASSED  = 1    // @emem not bypassed
};
typedef enum OtxTemuxBypassE OtxTemuxBypassE;

/******************************************************************************
  @enum 
    Temux PDH subsystem data path configuration for system side interface
    (System interface Mode of Operation)

  @xref
    <f OtxTemuxSysIfModeCfg>
    <f OtxTemuxE1T1SpeCfg>

******************************************************************************/
enum OtxTemuxSysIfMode {
  OTX_TEMUX_SBI    = 0,   // @emem SBI  
  OTX_TEMUX_SBITR  = 1,   // @emem SBI-TR
  OTX_TEMUX_HMVIP  = 2    // @emem HMVIP
};
typedef enum OtxTemuxSysIfMode OtxTemuxSysIfMode;

/******************************************************************************
  @enum 
    Temux PDH subsystem data path configuration for SPE source

  @xref
    <f OtxTemuxMapperSpeCfg>

******************************************************************************/
enum OtxTemuxMapSpeSrc {
  OTX_TEMUX_T1E1  = 0,  // @emem T1E1 subsystem  
  OTX_TEMUX_DS3E3 = 1   // @emem DS3E3 subsystem
};
typedef enum OtxTemuxMapSpeSrc OtxTemuxMapSpeSrc;

/******************************************************************************
  @enum 
    Temux PDH subsystem data path configuration of T1/E1 tributary mapping 

  @xref
    <f OtxTemuxMapperTribCfg>
    <f OtxTemuxE1T1EgressTribTimingCfg>

******************************************************************************/
enum OtxTemuxMapTribMode {
  OTX_TEMUX_BIT_ASYN  = 0,  // @emem bit asynchronous  
  OTX_TEMUX_BYTE_SYNC = 1,  // @emem byte synchronous
  OTX_TEMUX_TVT       = 2   // @emem Transparent Virtual Tributary
};
typedef enum OtxTemuxMapTribMode OtxTemuxMapTribMode;

/******************************************************************************
  @enum 
    Temux PDH subsystem data path configuration of PDH tributary type 

  @xref
    <f OtxTemuxMapperTribCfg>
    <f OtxTemuxMx13SpeCfg>
    <f OtxTemuxE1T1SpeCfg>

******************************************************************************/
enum OtxTemuxPhdTrib {
  OTX_TEMUX_T1  = 0,  // @emem T1  
  OTX_TEMUX_E1  = 1   // @emem E1
};
typedef enum OtxTemuxPhdTrib OtxTemuxPhdTrib;

/******************************************************************************
  @enum 
    Temux PDH subsystem data path configuration for DS3 frame type 

  @xref
    <f OtxTemuxMx13SpeCfg>

******************************************************************************/
enum OtxTemuxDs3FrameType {
  OTX_TEMUX_M23   = 0,  // @emem M23  
  OTX_TEMUX_CBIT  = 1   // @emem Cbit parity
};
typedef enum OtxTemuxDs3FrameType OtxTemuxDs3FrameType;

/******************************************************************************
  @enum 
    Temux PDH subsystem data path configuration for Ingress data source 

  @xref
    <f OtxTemuxD3E3SpeDataPathCfg>

******************************************************************************/
enum OtxTemuxIngressSrc {
  OTX_TEMUX_I_RX_SERIAL = 0,  // @emem Rx Serial Interface 
  OTX_TEMUX_I_DS3E3MD   = 1   // @emem DS3E3MD
};
typedef enum OtxTemuxIngressSrc OtxTemuxIngressSrc;

/******************************************************************************
  @enum 
    Temux PDH subsystem data path configuration for Egress data source 

  @xref
    <f OtxTemuxD3E3SpeDataPathCfg>

******************************************************************************/
enum OtxTemuxEgressSrc {
  OTX_TEMUX_E_MX13        = 0,  // @emem MX13 
  OTX_TEMUX_E_TX_PAYLOAD  = 1,  // @emem Tx Payload Interface
  OTX_TEMUX_E_SBI         = 2   // @emem SBI Interface
};
typedef enum OtxTemuxEgressSrc OtxTemuxEgressSrc;

/******************************************************************************
  @enum 
    Temux PDH subsystem data path configuration for DS3/E3 framing

  @xref
    <f OtxTemuxD3E3SpeFrameCfg>

******************************************************************************/
enum OtxTemuxDs3e3Frame {
  OTX_TEMUX_E_DS3      = 0,  // @emem DS3 - unframed/clearchannel 
  OTX_TEMUX_E_E3       = 1,  // @emem E3 - unframed/clearchannel
  OTX_TEMUX_E_DS3_CBIT = 2,  // @emem DS3 - C-bit parity
  OTX_TEMUX_E_DS3_M23  = 3,  // @emem DS3- M23 framing
  OTX_TEMUX_E_E3_G751  = 4,  // @emem E3 - G.751
  OTX_TEMUX_E_E3_G832  = 5   // @emem E3 - G.832
};
typedef enum OtxTemuxDs3e3Frame OtxTemuxDs3e3Frame;

/******************************************************************************
  @enum 
    Temux PDH subsystem data path configuration format of LIU

  @xref
    <f OtxTemuxD3E3SpeLineIfCfg>

******************************************************************************/
enum OtxTemuxDs3e3Mode {
  OTX_TEMUX_DS3      = 0,  // @emem Interface format DS3  
  OTX_TEMUX_E3       = 1   // @emem Interface format E3 
};
typedef enum OtxTemuxDs3e3Mode OtxTemuxDs3e3Mode;

/******************************************************************************
  @enum 
    Temux PDH subsystem data path configuration Transmit/Receive signal polarity

  @xref
    <f OtxTemuxD3E3SpeLineIfCfg>

******************************************************************************/
enum OtxTemuxSignalPolarity {
  OTX_TEMUX_UNIPOLAR = 0,  // @emem LIU signal polarity unipolar 
  OTX_TEMUX_BIPOLAR  = 1   // @emem LIU signal polarity bipolar 
};
typedef enum OtxTemuxSignalPolarity OtxTemuxSignalPolarity;

/******************************************************************************
  @enum 
    Temux PDH subsystem data path configuration for Egress DS3/E3 timing source

  @xref
    <f OtxTemuxD3E3SpeTimingCfg>
    <f OtxTemuxD3E3SpeSbiCfg>

******************************************************************************/
enum OtxTemuxTimingMode {
  OTX_TEMUX_SBI_EGRESS     = 0,  // @emem SBI Egress Data Rate
  OTX_TEMUX_LINK_RATE      = 1,  // @emem Link Rate Octet 
  OTX_TEMUX_TICLK          = 2,  // @emem TICLK
  OTX_TEMUX_DS3E3_REF_CLK  = 3,  // @emem DS3REFCLK/E3REFCLK 
  OTX_TEMUX_DS3E3_RECOVER  = 4   // @emem DS3/E3 Recovered Clock 
};
typedef enum OtxTemuxTimingMode OtxTemuxTimingMode;

/******************************************************************************
  @enum 
    Temux PDH subsystem data path configuration for DS3/E3 payload frame type

  @xref
    <f OtxTemuxD3E3SpeSbiCfg>

******************************************************************************/
enum OtxTemuxPayload {
  OTX_TEMUX_DS3_FRAMED     = 0,  // @emem framed DS3
  OTX_TEMUX_DS3_UNFRAMED   = 1,  // @emem unframed DS3 
  OTX_TEMUX_E3_FRAMED      = 2,  // @emem framed E3
  OTX_TEMUX_E3_UNFRAMED    = 3   // @emem unframed E3 
};
typedef enum OtxTemuxPayload OtxTemuxPayload;

/******************************************************************************
  @enum 
    Temux PDH subsystem data path configuration T1E1 Data path configuration

  @xref
    <f OtxTemuxE1T1SpeCfg>

******************************************************************************/
enum OtxTemuxSpeDest {
  OTX_TEMUX_TRIBXC     = 0,  // @emem TRIBXC/MX13 
  OTX_TEMUX_MAPPER     = 1   // @emem Mapper 
};
typedef enum OtxTemuxSpeDest OtxTemuxSpeDest;

/******************************************************************************
  @enum 
    Temux PDH subsystem data path configuration T1/E1 framing mode

  @xref
    <f OtxTemuxE1T1TribFrameCfg>

******************************************************************************/
enum OtxTemuxFrameMode {
  OTX_TEMUX_T1_UNFRAMED = 0,  // @emem T1 Unframed
  OTX_TEMUX_T1_ESF      = 1,  // @emem T1 ESF
  OTX_TEMUX_T1_SF       = 2,  // @emem T1 SF
  OTX_TEMUX_E1_UNFRAMED = 3,  // @emem E1 Unframed
  OTX_TEMUX_E1_STANDARD = 4,  // @emem E1 Standard
  OTX_TEMUX_E1_CRC      = 5,  // @emem E1 CRC
  OTX_TEMUX_E1_CAS      = 6,  // @emem E1 CAS
  OTX_TEMUX_E1_CAS_CRC  = 7   // @emem E1 CAS + CRC
};
typedef enum OtxTemuxFrameMode OtxTemuxFrameMode;

/******************************************************************************
  @enum 
    Temux PDH subsystem data path configuration ingress/egress elastic buffer

  @xref
    <f OtxTemuxE1T1IngressTribTimingCfg>
    <f OtxTemuxE1T1EgressTribTimingCfg>

******************************************************************************/
enum OtxTemuxELST {
  OTX_TEMUX_ELST_DATAPATH = 0,  // @emem RX_ELST/TX_ELST is in the data path
  OTX_TEMUX_ELST_BYPASSED = 1   // @emem RX_ELST/TX_ELST is bypassed
};
typedef enum OtxTemuxELST OtxTemuxELST;

/******************************************************************************
  @enum 
    Temux PDH subsystem data path configuration ingress tributary timing mode

  @xref
    <f OtxTemuxE1T1IngressTribTimingCfg>

******************************************************************************/
enum OtxTemuxRxTiming {
  OTX_TEMUX_RX_TT_RTDM  = 0, // @emem RTDM (bit asynchronously demapped)
  OTX_TEMUX_RX_TT_EXSBI = 1, // @emem Mapper EXSBI (byte synchronously demapped)
  OTX_TEMUX_RX_TT_MX13  = 2, // @emem MX13 (demultiplexed from DS3)
  OTX_TEMUX_RX_TT_MUX   = 3  // @emem Transmux Mode
};
typedef enum OtxTemuxRxTiming OtxTemuxRxTiming;

/******************************************************************************
  @enum 
    Temux PDH subsystem data path configuration egress tributary timing mode

  @xref
    <f OtxTemuxE1T1EgressTribTimingCfg>

******************************************************************************/
enum OtxTemuxTxTiming {
  OTX_TEMUX_TX_TT_LOOP  = 0, // @emem Loop Timing
  OTX_TEMUX_TX_TT_CTCLK = 1, // @emem CTCLK or internally recovered clock
  OTX_TEMUX_TX_TT_DSSI  = 2, // @emem Data from System Side Interface
  OTX_TEMUX_TX_TT_TISS  = 3, // @emem Timing Information from System Side interface
  OTX_TEMUX_TX_TT_MUX   = 4  // @emem Transmux Mode
};
typedef enum OtxTemuxTxTiming OtxTemuxTxTiming;

/******************************************************************************
  @enum 
    Temux PDH subsystem data path configuration of tributary synchronous or 
    asynchronous on SBI Add and Drop Bus

  @xref
    <f OtxTemuxE1T1TribSbiCfg>

******************************************************************************/
enum OtxTemuxSync {
  OTX_TEMUX_ASYNC  = 0,  // @emem asynchronous  
  OTX_TEMUX_SYNC   = 1   // @emem synchronous
};
typedef enum OtxTemuxSync OtxTemuxSync;

/******************************************************************************
  @enum 
    Temux PDH subsystem data path configuration of tributary T1/E1 or  
    Transparent Virtual Tributary (TVT) on SBI Add and Drop Bus

  @xref
    <f OtxTemuxE1T1TribSbiCfg>

******************************************************************************/
enum OtxTemuxMode {
  OTX_TEMUX_SBI_T1E1  = 0,  // @emem T1E1 rate tributary mode 
  OTX_TEMUX_SBI_TVT   = 1   // @emem TVT mode
};
typedef enum OtxTemuxMode OtxTemuxMode;


/*******************************************************************************

  @struct
    Specific details for the single destination to the four sources that 
    were passed to the OtxTemuxStsiDestPortCfg function.

  @xref
    <f OtxTemuxGetInfo>
    <t OtxTemuxGetTemuxInfoS>
    <f OtxTemuxStsiDestPortCfg>

*******************************************************************************/
struct OtxTemuxStsiDestSrcS {
  OtxTemuxDestPortE  eDataLinkDestination;                // @field Destination
  OtxTemuxSrcPortE   eDataLinkSource[OTX_TEMUX_MAX_LINK]; // @field Source
};
typedef struct OtxTemuxStsiDestSrcS OtxTemuxStsiDestSrcS;

/*******************************************************************************

  @struct
    Specific details for the subsystem data path configuration that 
    were passed to the OtxTemuxSysIfModeCfg function.

  @xref
    <f OtxTemuxGetInfo>
    <f OtxTemuxSysIfModeCfg>

*******************************************************************************/
struct OtxTemuxSysIfModeS {
  OtxTemuxSysIfMode eSysIfMode; // @field System side (0-SBI 1-SBI-TR 2-HMVIP)
  OTX_BOOL          nParam[5];  // @field parameters 1-5
};
typedef struct OtxTemuxSysIfModeS OtxTemuxSysIfModeS;

/*******************************************************************************

  @struct
    Specific details of the current Line Interface (Li) Devices status. 

  @xref
    <f OtxTemuxGetLiStatus>
    <t OtxTemuxVtTypeE>

*******************************************************************************/
struct OtxTemuxGetLiStatusS {
  OtxTemuxVtTypeE   eVtType;       // @field VT-2 E1; VT-15 T1
  OTX_BOOL          bTxPinEnabled; // @field State of the Line Interface 
};
typedef struct OtxTemuxGetLiStatusS OtxTemuxGetLiStatusS;

/*******************************************************************************

  @struct
    Specific details of the Temux device used to display a configuration
    of the device after the device is configured during the user configuration.

    Note this is mainly used for debug.

  @xref
    <f OtxTemuxGetInfo>

*******************************************************************************/
struct OtxTemuxGetTemuxInfoS {
  OTX_UINT32            nNumSpans;                                             // @field Number of spans supported 
  OTX_BOOL              bClockConfig[OTX_TEMUX_MAX_LINK];                      // @field SONET/SDH Clock is configured
  OtxTemuxClockSrcE     eClkSrcMode[OTX_TEMUX_MAX_LINK];                       // @field OtxTemuxClockSrcE
  OtxTemuxDataLinkSrcE  eDataLinkSource[OTX_TEMUX_MAX_LINK];                   // @field OtxTemuxDataLinkSrcE
  OtxTemuxIntfModeE     eIntfMode;                                             // @field Physical interface used
  OtxTemuxLinkSrcE      eLinkSrc[OTX_TEMUX_MAX_LINK];                          // @field Working and protect line side 
  OtxTemuxSts12Concat   eSts12Concatenation[OTX_TEMUX_MAX_LINK];               // @field Payload configuration
  OtxTemuxSts3Concat    eSts3Concatenation[OTX_TEMUX_MAX_LINK];                // @field Payload configuration
  OtxTemuxStsiDestSrcS  sStreamConnection[OTX_TEMUX_MAX_LINK];                 // @field Destination to source
  OtxTemuxSts12PayloadE eSts12Payload;                                         // @field OtxTemuxSts12PayloadE
  OtxTemuxDevConfigureE eConfigMode;                                           // @field Configuration mode 
  OtxTemuxInterfaceE    eHwInterface;                                          // @field SBI or HMVIP
  OtxTemuxSts1PayloadE  eSts1Payload[OTX_TEMUX_MAX_LINK][OTX_TEMUX_MAX_STS1];  
  OtxTemuxVtTypeE       eVtGroupPayload[OTX_TEMUX_MAX_LINK][OTX_TEMUX_MAX_STS1][OTX_TEMUX_MAX_VTGROUP];
  OtxTemuxSysIfModeS    sStsiDestSrc;
  OtxTemuxSysIfMode     eSysIfMode[OTX_TEMUX_MAX_LINK][OTX_TEMUX_MAX_STS1];
  OtxTemuxSpeDest       eSpeDest[OTX_TEMUX_MAX_LINK][OTX_TEMUX_MAX_STS1];
  OtxTemuxPhdTrib       ePhdTribType[OTX_TEMUX_MAX_LINK][OTX_TEMUX_MAX_STS1];
  OtxTemuxMapSpeSrc     eMapSpeSrc[OTX_TEMUX_MAX_LINK][OTX_TEMUX_MAX_STS1];
  OtxTemuxFrameMode     eFrameMode[OTX_TEMUX_MAX_LINK][OTX_TEMUX_MAX_STS1][OTX_TEMUX_MAX_TRIB];
  OtxTemuxELST          eBypassModeIngress[OTX_TEMUX_MAX_LINK][OTX_TEMUX_MAX_STS1][OTX_TEMUX_MAX_TRIB];
  OtxTemuxRxTiming      eTimingIngress[OTX_TEMUX_MAX_LINK][OTX_TEMUX_MAX_STS1][OTX_TEMUX_MAX_TRIB];
  OtxTemuxELST          eBypassModeEgress[OTX_TEMUX_MAX_LINK][OTX_TEMUX_MAX_STS1][OTX_TEMUX_MAX_TRIB];
  OtxTemuxTxTiming      eTimingEgress[OTX_TEMUX_MAX_LINK][OTX_TEMUX_MAX_STS1][OTX_TEMUX_MAX_TRIB];
  OtxTemuxMapTribMode   eSrcOrDestEgress[OTX_TEMUX_MAX_LINK][OTX_TEMUX_MAX_STS1][OTX_TEMUX_MAX_TRIB];
  OtxTemuxMapTribMode   eMapTribMode[OTX_TEMUX_MAX_LINK][OTX_TEMUX_MAX_STS1][OTX_TEMUX_MAX_TRIB];
  OtxTemuxPhdTrib       eMapPhdTribType[OTX_TEMUX_MAX_LINK][OTX_TEMUX_MAX_STS1][OTX_TEMUX_MAX_TRIB];
  OtxTemuxVtTypeE       eMapSonetTribType[OTX_TEMUX_MAX_LINK][OTX_TEMUX_MAX_STS1][OTX_TEMUX_MAX_TRIB];
  OtxTemuxSync          eT1E1SyncTrib[OTX_TEMUX_MAX_LINK][OTX_TEMUX_MAX_STS1][OTX_TEMUX_MAX_TRIB];
  OTX_BOOL              bT1E1Enable[OTX_TEMUX_MAX_LINK][OTX_TEMUX_MAX_STS1][OTX_TEMUX_MAX_TRIB];
  OtxTemuxMode          eT1E1RateMode[OTX_TEMUX_MAX_LINK][OTX_TEMUX_MAX_STS1][OTX_TEMUX_MAX_TRIB];
};
typedef struct OtxTemuxGetTemuxInfoS OtxTemuxGetTemuxInfoS;

#ifdef __cplusplus
}// extern "C"
#endif



/*******************************************************************************

  Copyright (C) Odin TeleSystems Inc., 2010

  All rights reserved. No part of this computer program may be reproduced,
  stored in any retrieval system, or transmitted, in any form or by any
  means, electronic, mechanical, photocopying, recording, or otherwise,
  without the prior written permission of Odin TeleSystems Inc., or without
  a permission stipulated in the agreement/contract under which this computer
  program was supplied.

*******************************************************************************/
#endif  // OTX_TEMUX_DEF_H
